pub struct WebhookIntegration { /* private fields */ }Expand description
Webhook integration for processing events
Implementations
Sourceimpl WebhookIntegration
impl WebhookIntegration
pub async fn new( config: WebhookConfig, app_manager: Arc<dyn AppManager + Send + Sync>, queue_manager: Option<Arc<QueueManager>>, ) -> Result<Self>
pub fn is_enabled(&self) -> bool
pub async fn send_channel_occupied( &self, app: &App, channel: &str, ) -> Result<()>
pub async fn send_channel_vacated(&self, app: &App, channel: &str) -> Result<()>
pub async fn send_member_added( &self, app: &App, channel: &str, user_id: &str, ) -> Result<()>
pub async fn send_member_removed( &self, app: &App, channel: &str, user_id: &str, ) -> Result<()>
pub async fn send_client_event( &self, app: &App, channel: &str, event_name: &str, event_data: Value, socket_id: Option<&str>, user_id: Option<&str>, ) -> Result<()>
pub async fn send_cache_missed(&self, app: &App, channel: &str) -> Result<()>
Sourcepub async fn send_subscription_count_changed(
&self,
app: &App,
channel: &str,
subscription_count: usize,
) -> Result<()>
pub async fn send_subscription_count_changed( &self, app: &App, channel: &str, subscription_count: usize, ) -> Result<()>
Sends a webhook when the subscription count for a channel changes.
Sourcepub async fn check_queue_health(&self) -> Result<()>
pub async fn check_queue_health(&self) -> Result<()>
Check the health of the queue manager used by webhook integration